@@ -868,19 +868,19 @@ key_press_event_cb (GtkWidget   *widget,
 	delta = 0;
 
 	switch (event->keyval) {
-	case GDK_Left:
+	case GDK_KEY_Left:
 		property = "image-x-align";
 		delta = -0.01;
 		break;
-	case GDK_Right:
+	case GDK_KEY_Right:
 		property = "image-x-align";
 		delta = 0.01;
 		break;
-	case GDK_Up:
+	case GDK_KEY_Up:
 		property = "image-y-align";
 		delta = -0.01;
 		break;
-	case GDK_Down:
+	case GDK_KEY_Down:
 		property = "image-y-align";
 		delta = 0.01;
 		break;
@@ -1053,8 +1053,8 @@ eog_print_preview_draw (EogPrintPreview *preview, cairo_t *cr)
 	}
 
 	if (has_focus) {
-		gtk_paint_focus (style, gtk_widget_get_window (area),
-				 GTK_STATE_NORMAL, NULL, NULL, NULL,
+		gtk_paint_focus (style, cr,
+				 GTK_STATE_NORMAL, NULL, NULL,
 				 0, 0, allocation.width, allocation.height);
 	}
 }
