@@ -35,6 +35,7 @@
 
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
+#include <stdlib.h>
 #include <string.h>
 
 #define EOG_THUMB_VIEW_SPACING 0
@@ -70,23 +71,23 @@ eog_thumb_view_finalize (GObject *object)
 }
 
 static void
-eog_thumb_view_destroy (GtkObject *object)
+eog_thumb_view_destroy (GtkWidget *object)
 {
 	EogThumbView *thumbview;
 	g_return_if_fail (EOG_IS_THUMB_VIEW (object));
 	thumbview = EOG_THUMB_VIEW (object);
 
-	GTK_OBJECT_CLASS (eog_thumb_view_parent_class)->destroy (object);
+	GTK_WIDGET_CLASS (eog_thumb_view_parent_class)->destroy (object);
 }
 
 static void
 eog_thumb_view_class_init (EogThumbViewClass *class)
 {
 	GObjectClass *gobject_class = G_OBJECT_CLASS (class);
-	GtkObjectClass *object_class = GTK_OBJECT_CLASS (class);
+	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (class);
 
 	gobject_class->finalize = eog_thumb_view_finalize;
-	object_class->destroy = eog_thumb_view_destroy;
+	widget_class->destroy = eog_thumb_view_destroy;
 
 	g_type_class_add_private (class, sizeof (EogThumbViewPrivate));
 }
@@ -224,7 +225,7 @@ thumbview_on_adjustment_changed_cb (EogThumbView *thumbview,
 
 static void
 thumbview_on_parent_set_cb (GtkWidget *widget,
-			    GtkObject *old_parent,
+			    GtkWidget *old_parent,
 			    gpointer   user_data)
 {
 	EogThumbView *thumbview = EOG_THUMB_VIEW (widget);
@@ -816,6 +817,10 @@ eog_thumb_view_select_single (EogThumbView *thumbview,
 		case EOG_THUMB_VIEW_SELECT_LEFT:
 		case EOG_THUMB_VIEW_SELECT_LAST:
 			path = gtk_tree_path_new_from_indices (n_items - 1, -1);
+			break;
+		case EOG_THUMB_VIEW_SELECT_RANDOM:
+			path = gtk_tree_path_new_from_indices ((int)(((float)(n_items - 1) * rand()) / (float)(RAND_MAX + 1.f)), -1);
+			break;
 		}
 	} else {
 		list = gtk_icon_view_get_selected_items (GTK_ICON_VIEW (thumbview));
@@ -849,6 +854,11 @@ eog_thumb_view_select_single (EogThumbView *thumbview,
 		case EOG_THUMB_VIEW_SELECT_LAST:
 			gtk_tree_path_free (path);
 			path = gtk_tree_path_new_from_indices (n_items - 1, -1);
+			break;
+		case EOG_THUMB_VIEW_SELECT_RANDOM:
+			gtk_tree_path_free (path);
+			path = gtk_tree_path_new_from_indices ((int)(((float)(n_items - 1) * rand()) / (float)(RAND_MAX + 1.f)), -1);
+			break;
 		}
 	}
 
@@ -861,7 +871,7 @@ eog_thumb_view_select_single (EogThumbView *thumbview,
 
 /**
  * eog_thumb_view_set_thumbnail_popup:
- * @thumbview: A #GtkThumbView.
+ * @thumbview: An #EogThumbView.
  * @menu: A #GtkMenu.
  *
  * Set the contextual menu to be used with the thumbnails in the
